==> haskell-hpack-0.35.5-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.35.5
visibility:           public
id:                   hpack-0.35.5-LeAcHnznxiaIiloT80eXMF
key:                  hpack-0.35.5-LeAcHnznxiaIiloT80eXMF
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  4ac0ca2a4611e53cd304770521dd714d
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.5-LeAcHnznxiaIiloT80eXMF
depends:
    Cabal-3.8.1.0 Glob-0.10.2-LcArkx2vrCQ6596mMQlWm
    aeson-2.1.2.1-AuEsVg6Hhe2CPhaLp40FYe base-4.17.2.1
    bifunctors-5.6.2-DAZdgoI3BboBP5wt8Vs1PE bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.3-F6dXvDAkkF64nCV5EYjfDZ
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    http-client-0.7.19-veq4MTHniy21v9pOYpRdd
    http-client-tls-0.3.6.4-BtAmNja0oKIEdL14Ub64ie
    http-types-0.12.4-KxfEKIoLDdBKlrGUyHct4y
    infer-license-0.2.0-89vCZUpCfctHmmogj0SeVd pretty-1.1.3.6
    scientific-0.3.8.0-LCs3zqD3ZVT6NyF8Z7YnMi text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-FOY8P5Y3sqjANbVUEJi9Vi
    vector-0.13.2.0-6oLw41loWTIuQEg8iaHmr
    yaml-0.11.11.2-46QNKBlQxe67SIHc4SHjVB

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.35.5-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.35.5
visibility:           public
id:                   hpack-0.35.5-3aCO9T7wYW9An4MTLNoPlY
key:                  hpack-0.35.5-3aCO9T7wYW9An4MTLNoPlY
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  e237b58cb398577b81e59e6cfcb80413
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.5-3aCO9T7wYW9An4MTLNoPlY
depends:
    Cabal-3.8.1.0 Glob-0.10.2-6MAgOFTrZnr5duqQgX06z4
    aeson-2.1.2.1-6ANjbGmrSDg8K6hz3VmYXP base-4.17.2.1
    bifunctors-5.6.2-ASXTwgeHUT09TqDX9FqnHc bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.3-4ze0wyRfIfo3Yl9n4jOf0m
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    http-client-0.7.19-INRexYbbc84G8M9afYhYa4
    http-client-tls-0.3.6.4-4b1LqwZqELbD3PiYpWlMw1
    http-types-0.12.4-BDAI9vbdFnhAzARYRhzpQY
    infer-license-0.2.0-Hq0vHkP9PCxJPWE8IhD0WF pretty-1.1.3.6
    scientific-0.3.8.0-eAJHzbOczMAHNfebkRy2Z text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7
    vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH
    yaml-0.11.11.2-6eLqTH2y8Fa133KzujCnx8

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
